import axios from 'axios';
import qs from 'query-string';
import type { DescData } from '@arco-design/web-vue/es/descriptions/interface';

export interface PolicyRecord {
  id: string;
  number: number;
  name: string;
  contentType: 'img' | 'horizontalVideo' | 'verticalVideo';
  filterType: 'artificial' | 'rules';
  count: number;
  status: 'online' | 'offline';
  createdTime: string;
}

export interface PolicyParams extends Partial<PolicyRecord> {
  current: number;
  pageSize: number;
}

export interface PolicyListRes {
  list: PolicyRecord[];
  total: number;
}
// 知识库列表接口
export function queryKbList(params) {
  return axios.get('/api/v1/kb/list', {
    params
  });
}
// 知识库详情接口
export function queryKbdetail(params) {
  return axios.get('/api/v1/kb/detail', {
    params
  });
}

// 信息接口
export function queryKbtenantInfo(params) {
  return axios.get('/api/v1/user/tenant_info', {
    params
  });
}
// 文档列表接口
export function queryKbDocumentList(params) {
  return axios.get('/api/v1/document/list', {
    params
  });
}

// 知识库创建接口
export function kbcreate(params) {
  return axios.post('/api/v1/kb/create', params);
}
// 知识库删除接口
export function deleteKnow(params) {
  return axios.post('/api/v1/kb/rm', params);
}
//知识库更新接口

export function querykbupdate(params) {
  return axios.post('/api/v1/kb/update', params);
}

// 文档上传接口

// export function kbdocumentupload(params) {
//   return axios.post('/api/v1/document/upload', params);
// }

export function kbdocumentupload(params) {
  const config = {
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
      // token: token,
    },
  }
  return axios.post(
    '/api/v1/document/upload',
    params,
    config
  )
}


// 文档启动/取消解析接口

export function kbdocumentrun(params) {
  return axios.post('/api/v1/document/run', params);
}

// 文档删除接口

export function kbdocumentrm(params) {
  return axios.post('/api/v1/document/rm', params);
}


// 文档重命名接口
export function kbdocumentrename(params) {
  return axios.post('/api/v1/document/rename', params);
}
// 文件解析方法接口
export function kbdocumentchangeparser(params) {
  return axios.post('/api/v1/document/change_parser', params);
}

















